floaty_chatheads_platform_interface library

Classes

AddChatHeadConfig
Configuration for adding a chathead bubble to an existing group.
ChatHeadConfig
Configuration for showing a floating chathead.
ChatHeadTheme
Theming configuration for the floating chathead.
FloatyChatheadsPlatform
The interface that implementations of floaty_chatheads must implement.
OverlayPosition
The on-screen position of the overlay window.

Enums

ContentSizePreset
Named size presets for the chathead content panel.
EntranceAnimation
Animation style used when the chathead first appears on screen (Android).
NotificationVisibility
Visibility level of the foreground-service notification (Android).
OverlayFlag
Window behavior flags for the overlay.
SnapEdge
Which screen edge(s) the chathead snaps to after being released (Android).